==> makeen-expressionengine-0.0.51.tgz: package/src/functions/globals/switch.ts <==
﻿import { mfunction } from './../mfunction'
import expressionData from '../../expressionData'
import { expressionPart } from './../../compiler/parts/expressionPart'
import { switchParameterPart } from './../../compiler/parts/switchParameterPart'
import { switchCasePart } from './../../compiler/parts/switchCasePart'
import { utils } from './../../compiler/utils'
import { List } from 'typescript-dotnet-commonjs/System/Collections/List'
import { groupDataContext } from './../../functions/groupDataContext'
import { compileFlags } from '../../compiler/expressionCompiler'
import { outputVariables } from '../../utils/outputVariables'


export class aswitch extends mfunction {

    public /* override */ get minParameters(): number {
        return 1;
    }

    public /* override */ get maxParameters(): number {
        return -1;
    }

    public compileParameters(paramList: List<string>, flags: compileFlags): List<expressionPart> {
        let parameters: List<expressionPart> = new List<expressionPart>();
        let switParameter = new switchParameterPart();
        flags.switchCasePart = true;
        let compileOjbect = new compileFlags(flags);
        compileOjbect.switchCasePart = true;
        switParameter.switchData = utils.buildSwitchCaseOverload(paramList, compileOjbect);
         //switParameter.switchData = true;
        parameters.add(switParameter);
        return parameters;
    }

    public invoke(expressionData: expressionData, parameters: List<expressionPart>, /* out */resolved: outputVariables, running: groupDataContext): Object | undefined {
        if (parameters.get(0) instanceof switchParameterPart) {
            let part: switchParameterPart = (<switchParameterPart>parameters.get(0));
            return part.resolve(expressionData, /* out */resolved, /* running:*/ running);
        }
        else {
           resolved.resolved = false;
            return undefined;
        }

    }
}

==> makeen-expressionengine-0.0.63.tgz: package/src/functions/globals/switch.ts <==
﻿import { mfunction } from './../mfunction'
import expressionData from '../../expressionData'
import { expressionPart } from './../../compiler/parts/expressionPart'
import { switchParameterPart } from './../../compiler/parts/switchParameterPart'
import { switchCasePart } from './../../compiler/parts/switchCasePart'
import { utils } from './../../compiler/utils'
import { List } from 'typescript-dotnet-commonjs/System/Collections/List'
import { groupDataContext } from './../../functions/groupDataContext'
import { compileFlags } from '../../compiler/expressionCompiler'
import { outputVariables } from '../../utils/outputVariables'


export class aswitch extends mfunction {

     /* override */ get minParameters(): number {
        return 1;
    }

     /* override */ get maxParameters(): number {
        return -1;
    }

     compileParameters(paramList: List<string>, flags: compileFlags) : expressionPart[] {
        let parameters: expressionPart[] = [];
        let switParameter = new switchParameterPart();
        flags.switchCasePart = true;
        let compileOjbect = new compileFlags(flags);
        compileOjbect.switchCasePart = true;
        switParameter.switchData = utils.buildSwitchCaseOverload(paramList, compileOjbect);
         //switParameter.switchData = true;
        parameters.push(switParameter);
        return parameters;
    }

     invoke(expressionData: expressionData, parameters: expressionPart[], /* out */resolved: outputVariables, running: groupDataContext): Object | undefined {
        if (parameters[0] instanceof switchParameterPart) {
            let part: switchParameterPart = (<switchParameterPart>parameters[0]);
            return part.resolve(expressionData, /* out */resolved, /* running:*/ running);
        }
        else {
           resolved.resolved = false;
            return undefined;
        }

    }
}
